==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.2.0.zip: setup/steps/forms/systemdata.php <==
<?php
/**
 * Project: 
 * Contenido Content Management System
 * 
 * Description: 
 * 
 * Requirements: 
 * @con_php_req 5
 *
 * @package    ContenidoBackendArea
 * @version    0.2
 * @author     unknown
 * @copyright  four for business AG <www.4fb.de>
 * @license    http://www.contenido.org/license/LIZENZ.txt
 * @link       http://www.4fb.de
 * @link       http://www.contenido.org
 * 
 * 
 * 
 * {@internal 
 *   created  unknown
 *   modified 2008-07-07, bilal arslan, added security fix
 *
 *   $Id$:
 * }}
 * 
 */
if(!defined('CON_FRAMEWORK')) {
    die('Illegal call');
}

class cSetupSystemData extends cSetupMask {
	function __construct($step, $previous, $next) {
		cSetupMask::__construct("templates/setup/forms/systemdata.tpl", $step);
		
		list($a_root_path, $a_root_http_path) = getSystemDirectories();
		
		cInitializeArrayKey($_SESSION, "dbhost", "");
		cInitializeArrayKey($_SESSION, "dbuser", "");
		cInitializeArrayKey($_SESSION, "dbname", "");
		cInitializeArrayKey($_SESSION, "dbpass", "");
		cInitializeArrayKey($_SESSION, "dbprefix", "");
		cInitializeArrayKey($_SESSION, "dbencoding", "");
		cInitializeArrayKey($_SESSION, "dbmode", "");
		
		if ((file_exists($a_root_path."/admin/data/config/config.php")) || (file_exists($a_root_path."/admin/includes/config.php")) || (file_exists($a_root_path."/drugcms/includes/config.php")) || (file_exists($a_root_path."/contenido/includes/config.php"))) {
			global $cfg;
			
			$contenido_host		= ""; // Just define the variables to avoid warnings in IDE
			$contenido_user		= "";
			$contenido_database = "";
			$contenido_password = "";
			
            if (file_exists($a_root_path."/admin/data/config/config.php")) {
                @include($a_root_path."/admin/data/config/config.php");
            }
            elseif (file_exists($a_root_path."/admin/includes/config.php")) {
                @include($a_root_path."/admin/includes/config.php");
            }
			elseif (file_exists($a_root_path."/drugcms/includes/config.php")) {
                @include($a_root_path."/drugcms/includes/config.php");
			}
			else {
                @include($a_root_path."/contenido/includes/config.php");
            }
            
			$aVars = array(
				"dbhost"    => $contenido_host,
				"dbuser"    => $contenido_user,
				"dbname"    => $contenido_database,
				"dbpass"    => $contenido_password,
				"dbprefix"  => $cfg["sql"]["sqlprefix"],
				"dbencoding" => ((strlen($cfg["database_encoding"])) ? $cfg["database_encoding"] : $contenido_charset),
				"dbmode"    => 'mysqli'
			);
							
			foreach ($aVars as $aVar => $sValue) {
				if ($_SESSION[$aVar] == "") {
					$_SESSION[$aVar] = $sValue;	
				}	
			}
		}
		
		$this->setHeader(i18n_setup("Database Parameters"));
		$this->_oStepTemplate->set("s", "TITLE", i18n_setup("Database Parameters"));
				
		switch ($_SESSION["setuptype"]) {
			case "setup":
				$this->_oStepTemplate->set("s", "DESCRIPTION", i18n_setup("Please enter the required database information. If you are unsure about the data, ask your provider or administrator.")." ".i18n_setup("If the database does not exist and your database user has the sufficient permissions, setup will create the database automatically."));
				break;
			case "upgrade":
				$this->_oStepTemplate->set("s", "DESCRIPTION", i18n_setup("Please enter the required database information. If the database data of your previous installation could have been read, the data will be inserted automatically. If you are unsure about the data, please ask your provider or administrator."));
				break;
			case "migration":
				$this->_oStepTemplate->set("s", "DESCRIPTION", i18n_setup("Please enter the required database information. Make sure you copied the data from your old installation (e.g. development or staging system) into a new database. Please enter the parameters of the new database."));
				break;
		}
		
		if ($_SESSION["dbprefix"] == "") {
			$_SESSION["dbprefix"] = "dzircms";
		}
		
		unset($_SESSION["install_failedchunks"]);
		unset($_SESSION["install_failedupgradetable"]);
		unset($_SESSION["configsavefailed"]);
		unset($_SESSION["htmlpath"]);
		unset($_SESSION["frontendpath"]);
		
		$dbhost = new cHTMLTextbox("dbhost", $_SESSION["dbhost"], 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		$dbname = new cHTMLTextbox("dbname", $_SESSION["dbname"], 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		$dbuser = new cHTMLTextbox("dbuser", $_SESSION["dbuser"], 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		
		if ($_SESSION["dbpass"] != "") {
			$mpass = str_repeat("✳", strlen($_SESSION["dbpass"]));	
		} else {
			$mpass = "";	
		}
		
		$dbpass = new cHTMLPasswordbox("dbpass", $mpass, 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		$dbpass->attachEventDefinition("onchange handler", "onchange", "document.setupform.dbpass_changed.value = 'true';");
		$dbpass->attachEventDefinition("onchange handler", "onkeypress", "document.setupform.dbpass_changed.value = 'true';");
		
		$dbpass_hidden = new cHTMLHiddenField("dbpass_changed", "false");
		
		$dbprefix = new cHTMLTextbox("dbprefix", $_SESSION["dbprefix"], 10, 30, '', ($_SESSION["setuptype"] != 'setup'));
		
        if ($_SESSION["setuptype"] == 'setup') {
            $aDbEncoding = array(
                array("swe7_swedish_ci",        "7bit Swedish (swe7)"),
                array("armscii8_general_ci",    "ARMSCII-8 Armenian (armscii8)"),
                array("big5_chinese_ci",        "Big5 Traditional Chinese (big5)"),
                array("binary",                 "Binary pseudo charset (binary)"),
                array("latin1_general_ci",      "cp1252 West European (latin1)"),
                array("dec8_swedisch_ci",       "DEC West European (dec8)"),
                array("cp852_general_ci",       "DOS Central European (cp852)"),
                array("keybcs2_general_ci",     "DOS Kamenicky Czech-Slovak (keybcs2)"),
                array("cp866_general_ci",       "DOS Russian (cp866)"),
                array("cp850_general_ci",       "DOS West European (cp850)"),
                array("ujis_japanese_ci",       "EUC-JP Japanese (ujis)"),
                array("euckr_korean_ci",        "EUC-KR Korean (euckr)"),
                array("gb2312_chinese_ci",      "GB2312 Simplified Chinese (gb2312)"),
                array("gbk_chinese_ci",         "GBK Simplified Chinese (gbk)"),
                array("geostd8_general_ci",     "GEOSTD8 Georgian (geostd8)"),
                array("hp8_english_ci",         "HP West European (hp8)"),
                array("latin2_general_ci",      "ISO 8859-2 Central European (latin2)"),
                array("greek_general_ci",       "ISO 8859-7 Greek (greek)"),
                array("hebrew_general_ci",      "ISO 8859-8 Hebrew (hebrew)"),
                array("latin5_turkish_ci",      "ISO 8859-9 Turkish (latin5)"),
                array("latin7_general_ci",      "ISO 8859-13 Baltic (latin7)"),
                array("koi8r_general_ci",       "KOI8-R Relcom Russian (koi8r)"),
                array("koi8u_general_ci",       "KOI8-U Ukrainian (koi8u)"),
                array("macce_general_ci",       "Mac Central European (macce)"),
                array("macroman_general_ci",    "Mac West European (macroman)"),
                array("sjis_japanese_ci",       "Shift-JIS Japanese (sjis)"),
                array("cp932_japanese_ci",      "SJIS for Windows Japanese (cp932)"),
                array("tis620_thai_ci",         "TIS620 Thai (tis620)"),
                array("ucs2_general_ci",        "UCS-2 Unicode (ucs2)"),
                array("eucjpms_japanese_ci",    "UJIS for Windows Japanese (eucjpms)"),
                array("ascii_general_ci",       "US ASCII (ascii)"),
                array("utf8_general_ci",        "UTF-8 Unicode (utf8)"),
                array("utf8mb4_general_ci",     "UTF-8 Unicode (utf8mb4)"),
                array("utf16_general_ci",       "UTF-16 Unicode (utf16)"),
                array("utf32_general_ci",       "UTF-32 Unicode (utf32)"),
                array("cp1256_general_ci",      "Windows Arabic (cp1256)"),
                array("cp1257_general_ci",      "Windows Baltic (cp1257)"),
                array("cp1250_general_ci",      "Windows Central European (cp1250)"),
                array("cp1251_general_ci",      "Windows Cyrillic (cp1251)"),
            );
            $dbencoding = new cHTMLSelectElement("dbencoding", 30);
            $dbencoding->autoFill($aDbEncoding);
            $dbencoding->setDefault((((strlen($_SESSION["dbencoding"])) && (in_array($_SESSION['dbencoding'], $aDbEncoding))) ? $_SESSION["dbencoding"] : 'utf8mb4_general_ci'));
        } else {
            $dbencoding = new cHTMLTextbox("dbencoding", $_SESSION["dbencoding"], 30, 255, '', true);
        }
		
		$_SESSION["dbmode"] = 'mysqli';
		
		$this->_oStepTemplate->set("s", "LABEL_DBHOST", i18n_setup("Server (IP or name)"));
		
		if ($_SESSION["setuptype"] == "setup") {
			$this->_oStepTemplate->set("s", "LABEL_DBNAME", i18n_setup("Name")." ".i18n_setup("(use empty or non-existant database)"));
		} else {
			$this->_oStepTemplate->set("s", "LABEL_DBNAME", i18n_setup("Name"));
		}
		
		$this->_oStepTemplate->set("s", "LABEL_DBUSERNAME", i18n_setup("Username"));
		$this->_oStepTemplate->set("s", "LABEL_DBPASSWORD", i18n_setup("Password"));
		$this->_oStepTemplate->set("s", "LABEL_DBPREFIX", i18n_setup("Table Prefix"));
		$this->_oStepTemplate->set("s", "LABEL_DBENCODING", i18n_setup("Encoding"));
	
		$this->_oStepTemplate->set("s", "INPUT_DBHOST", $dbhost->render());
		$this->_oStepTemplate->set("s", "INPUT_DBNAME", $dbname->render());
		$this->_oStepTemplate->set("s", "INPUT_DBUSERNAME", $dbuser->render());
		$this->_oStepTemplate->set("s", "INPUT_DBPASSWORD", $dbpass->render().$dbpass_hidden->render());
		$this->_oStepTemplate->set("s", "INPUT_DBPREFIX", $dbprefix->render());
		$this->_oStepTemplate->set("s", "INPUT_DBENCODING", $dbencoding->render());
		
		$this->setNavigation($previous, $next);
	}

	function _createNavigation () {
		$checkScript = '';
		if ($_SESSION["setuptype"] == "setup") {		
			$checkScript = 'var msg = ""; if (document.setupform.dbhost.value == "") { msg += "' . html_entity_decode(i18n_setup("You need to enter a database host."), ENT_COMPAT, 'UTF-8') . ' "; } if (document.setupform.dbname.value == "") { msg += "' . html_entity_decode(i18n_setup("You need to enter a database name."), ENT_COMPAT, 'UTF-8') . ' "; } if (document.setupform.dbuser.value == "") { msg += "' . html_entity_decode(i18n_setup("You need to enter a database user."), ENT_COMPAT, 'UTF-8') . ' "; } if (document.setupform.dbhost.value != "" && document.setupform.dbname.value != "" && document.setupform.dbuser.value != "") { document.setupform.submit(); } else { alert(msg); }';
		}
		
		$this->_oStepTemplate->set("s", "NEXT", '<input id="Next" type="image" src="../admin/images/submit.gif" style="width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'../admin/images/submit.gif\');" onmouseout="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit.gif\\\');\'; } else { this.src=\'../admin/images/submit.gif\'; }" onmouseover="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit_hover.gif\\\');\'; } else { this.src=\'../admin/images/submit_hover.gif\'; }" onload="this.imgnormal = \'../admin/images/submit.gif\'; this.imgover = \'../admin/images/submit_hover.gif\'; this.clickimgnormal = \'\'; this.clickimgover = \'\'; if (!this.init) {IEAlphaInit(this); IEAlphaApply(this, this.imgnormal); this.init = true;}" onclick="document.setupform.step.value = \''.$this->_bNextstep.'\';">');
		
		$this->_oStepTemplate->set("s", "BACK", '<input id="Prev" type="image" src="images/controls/back.gif" style="margin-right: 10px; width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'images/controls/back.gif\');" onclick="document.setupform.step.value = \''.$this->_bBackstep.'\';">');
	}			
}
?>

==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.3.2.zip: setup/steps/forms/systemdata.php <==
<?php
/**
 * Project: 
 * Contenido Content Management System
 * 
 * Description: 
 * 
 * Requirements: 
 * @con_php_req 5
 *
 * @package    ContenidoBackendArea
 * @version    0.2
 * @author     unknown
 * @copyright  four for business AG <www.4fb.de>
 * @license    http://www.contenido.org/license/LIZENZ.txt
 * @link       http://www.4fb.de
 * @link       http://www.contenido.org
 * 
 * 
 * 
 * {@internal 
 *   created  unknown
 *   modified 2008-07-07, bilal arslan, added security fix
 *
 *   $Id$:
 * }}
 * 
 */
if(!defined('CON_FRAMEWORK')) {
    die('Illegal call');
}

class cSetupSystemData extends cSetupMask {
	function __construct($step, $previous, $next) {
		cSetupMask::__construct("templates/setup/forms/systemdata.tpl", $step);
		
		list($a_root_path, $a_root_http_path) = getSystemDirectories();
		
		cInitializeArrayKey($_SESSION, "dbhost", "");
		cInitializeArrayKey($_SESSION, "dbuser", "");
		cInitializeArrayKey($_SESSION, "dbname", "");
		cInitializeArrayKey($_SESSION, "dbpass", "");
		cInitializeArrayKey($_SESSION, "dbprefix", "");
		cInitializeArrayKey($_SESSION, "dbencoding", "");
		cInitializeArrayKey($_SESSION, "dbmode", "");
		
		if ((file_exists($a_root_path."/admin/data/config/config.php")) || (file_exists($a_root_path."/admin/includes/config.php")) || (file_exists($a_root_path."/drugcms/includes/config.php")) || (file_exists($a_root_path."/contenido/includes/config.php"))) {
			global $cfg;
			
			$contenido_host		= ""; // Just define the variables to avoid warnings in IDE
			$contenido_user		= "";
			$contenido_database = "";
			$contenido_password = "";
			$contenido_charset	= 'utf8mb4_general_ci';
			
            if (file_exists($a_root_path."/admin/data/config/config.php")) {
                @include($a_root_path."/admin/data/config/config.php");
            }
            elseif (file_exists($a_root_path."/admin/includes/config.php")) {
                @include($a_root_path."/admin/includes/config.php");
            }
			elseif (file_exists($a_root_path."/drugcms/includes/config.php")) {
                @include($a_root_path."/drugcms/includes/config.php");
			}
			else {
                @include($a_root_path."/contenido/includes/config.php");
            }
            
			$aVars = array(
				"dbhost"  		=> $contenido_host,
				"dbuser"    	=> $contenido_user,
				"dbname"    	=> $contenido_database,
				"dbpass"    	=> $contenido_password,
				"dbprefix"  	=> $cfg["sql"]["sqlprefix"],
				"dbencoding" 	=> ((strlen($cfg["database_encoding"])) ? ((strpos($cfg["database_encoding"], '_') === false) ? $cfg["database_encoding"] . '_general_ci' : $cfg["database_encoding"]) : $contenido_charset),
				"dbmode"    	=> 'mysqli'
			);
							
			foreach ($aVars as $aVar => $sValue) {
				if ($_SESSION[$aVar] == "") {
					$_SESSION[$aVar] = $sValue;	
				}	
			}
		}
		
		$this->setHeader(i18n_setup("Database Parameters"));
		$this->_oStepTemplate->set("s", "TITLE", i18n_setup("Database Parameters"));
				
		switch ($_SESSION["setuptype"]) {
			case "setup":
				$this->_oStepTemplate->set("s", "DESCRIPTION", i18n_setup("Please enter the required database information. If you are unsure about the data, ask your provider or administrator.")." ".i18n_setup("If the database does not exist and your database user has the sufficient permissions, setup will create the database automatically."));
				break;
			case "upgrade":
				$this->_oStepTemplate->set("s", "DESCRIPTION", i18n_setup("Please enter the required database information. If the database data of your previous installation could have been read, the data will be inserted automatically. If you are unsure about the data, please ask your provider or administrator."));
				break;
			case "migration":
				$this->_oStepTemplate->set("s", "DESCRIPTION", i18n_setup("Please enter the required database information. Make sure you copied the data from your old installation (e.g. development or staging system) into a new database. Please enter the parameters of the new database."));
				break;
		}
		
		if ($_SESSION["dbprefix"] == "") {
			$_SESSION["dbprefix"] = "dzircms";
		}
		
		unset($_SESSION["install_failedchunks"]);
		unset($_SESSION["install_failedupgradetable"]);
		unset($_SESSION["configsavefailed"]);
		unset($_SESSION["htmlpath"]);
		unset($_SESSION["frontendpath"]);
		
		$dbhost = new cHTMLTextbox("dbhost", $_SESSION["dbhost"], 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		$dbname = new cHTMLTextbox("dbname", $_SESSION["dbname"], 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		$dbuser = new cHTMLTextbox("dbuser", $_SESSION["dbuser"], 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		
		if ($_SESSION["dbpass"] != "") {
			$mpass = str_repeat("✳", strlen($_SESSION["dbpass"]));	
		} else {
			$mpass = "";	
		}
		
		$dbpass = new cHTMLPasswordbox("dbpass", $mpass, 30, 255, '', ($_SESSION['setuptype'] == 'upgrade'));
		$dbpass->attachEventDefinition("onchange handler", "onchange", "document.setupform.dbpass_changed.value = 'true';");
		$dbpass->attachEventDefinition("onchange handler", "onkeypress", "document.setupform.dbpass_changed.value = 'true';");
		
		$dbpass_hidden = new cHTMLHiddenField("dbpass_changed", "false");
		
		$dbprefix = new cHTMLTextbox("dbprefix", $_SESSION["dbprefix"], 10, 30, '', ($_SESSION["setuptype"] != 'setup'));
		
		$aDbEncoding = array(
			array("swe7_swedish_ci",        "7bit Swedish (swe7)"),
			array("armscii8_general_ci",    "ARMSCII-8 Armenian (armscii8)"),
			array("big5_chinese_ci",        "Big5 Traditional Chinese (big5)"),
			array("binary",                 "Binary pseudo charset (binary)"),
			array("latin1_general_ci",      "cp1252 West European (latin1)"),
			array("dec8_swedisch_ci",       "DEC West European (dec8)"),
			array("cp852_general_ci",       "DOS Central European (cp852)"),
			array("keybcs2_general_ci",     "DOS Kamenicky Czech-Slovak (keybcs2)"),
			array("cp866_general_ci",       "DOS Russian (cp866)"),
			array("cp850_general_ci",       "DOS West European (cp850)"),
			array("ujis_japanese_ci",       "EUC-JP Japanese (ujis)"),
			array("euckr_korean_ci",        "EUC-KR Korean (euckr)"),
			array("gb2312_chinese_ci",      "GB2312 Simplified Chinese (gb2312)"),
			array("gbk_chinese_ci",         "GBK Simplified Chinese (gbk)"),
			array("geostd8_general_ci",     "GEOSTD8 Georgian (geostd8)"),
			array("hp8_english_ci",         "HP West European (hp8)"),
			array("latin2_general_ci",      "ISO 8859-2 Central European (latin2)"),
			array("greek_general_ci",       "ISO 8859-7 Greek (greek)"),
			array("hebrew_general_ci",      "ISO 8859-8 Hebrew (hebrew)"),
			array("latin5_turkish_ci",      "ISO 8859-9 Turkish (latin5)"),
			array("latin7_general_ci",      "ISO 8859-13 Baltic (latin7)"),
			array("koi8r_general_ci",       "KOI8-R Relcom Russian (koi8r)"),
			array("koi8u_general_ci",       "KOI8-U Ukrainian (koi8u)"),
			array("macce_general_ci",       "Mac Central European (macce)"),
			array("macroman_general_ci",    "Mac West European (macroman)"),
			array("sjis_japanese_ci",       "Shift-JIS Japanese (sjis)"),
			array("cp932_japanese_ci",      "SJIS for Windows Japanese (cp932)"),
			array("tis620_thai_ci",         "TIS620 Thai (tis620)"),
			array("ucs2_general_ci",        "UCS-2 Unicode (ucs2)"),
			array("eucjpms_japanese_ci",    "UJIS for Windows Japanese (eucjpms)"),
			array("ascii_general_ci",       "US ASCII (ascii)"),
			array("utf8_general_ci",        "UTF-8 Unicode (utf8)"),
			array("utf8mb4_general_ci",     "UTF-8 Unicode (utf8mb4)"),
			array("utf16_general_ci",       "UTF-16 Unicode (utf16)"),
			array("utf32_general_ci",       "UTF-32 Unicode (utf32)"),
			array("cp1256_general_ci",      "Windows Arabic (cp1256)"),
			array("cp1257_general_ci",      "Windows Baltic (cp1257)"),
			array("cp1250_general_ci",      "Windows Central European (cp1250)"),
			array("cp1251_general_ci",      "Windows Cyrillic (cp1251)"),
		);
		$dbencoding = new cHTMLSelectElement("dbencoding", 30);
		$dbencoding->autoFill($aDbEncoding);
		$dbencoding->setDefault((((strlen($_SESSION["dbencoding"])) && (in_array($_SESSION['dbencoding'], $aDbEncoding))) ? $_SESSION["dbencoding"] : $contenido_charset));
        if ($_SESSION["setuptype"] != 'setup') {
			$dbencoding->setDisabled('disabled');
        }
		
		$_SESSION["dbmode"] = 'mysqli';
		
		$this->_oStepTemplate->set("s", "LABEL_DBHOST", i18n_setup("Server (IP or name)"));
		
		if ($_SESSION["setuptype"] == "setup") {
			$this->_oStepTemplate->set("s", "LABEL_DBNAME", i18n_setup("Name")." ".i18n_setup("(use empty or non-existant database)"));
		} else {
			$this->_oStepTemplate->set("s", "LABEL_DBNAME", i18n_setup("Name"));
		}
		
		$this->_oStepTemplate->set("s", "LABEL_DBUSERNAME", i18n_setup("Username"));
		$this->_oStepTemplate->set("s", "LABEL_DBPASSWORD", i18n_setup("Password"));
		$this->_oStepTemplate->set("s", "LABEL_DBPREFIX", i18n_setup("Table Prefix"));
		$this->_oStepTemplate->set("s", "LABEL_DBENCODING", i18n_setup("Encoding"));
	
		$this->_oStepTemplate->set("s", "INPUT_DBHOST", $dbhost->render());
		$this->_oStepTemplate->set("s", "INPUT_DBNAME", $dbname->render());
		$this->_oStepTemplate->set("s", "INPUT_DBUSERNAME", $dbuser->render());
		$this->_oStepTemplate->set("s", "INPUT_DBPASSWORD", $dbpass->render().$dbpass_hidden->render());
		$this->_oStepTemplate->set("s", "INPUT_DBPREFIX", $dbprefix->render());
		$this->_oStepTemplate->set("s", "INPUT_DBENCODING", $dbencoding->render());
		
		$this->setNavigation($previous, $next);
	}

	function _createNavigation () {
		$checkScript = '';
		if ($_SESSION["setuptype"] == "setup") {		
			$checkScript = 'var msg = ""; if (document.setupform.dbhost.value == "") { msg += "' . html_entity_decode(i18n_setup("You need to enter a database host."), ENT_COMPAT, 'UTF-8') . ' "; } if (document.setupform.dbname.value == "") { msg += "' . html_entity_decode(i18n_setup("You need to enter a database name."), ENT_COMPAT, 'UTF-8') . ' "; } if (document.setupform.dbuser.value == "") { msg += "' . html_entity_decode(i18n_setup("You need to enter a database user."), ENT_COMPAT, 'UTF-8') . ' "; } if (document.setupform.dbhost.value != "" && document.setupform.dbname.value != "" && document.setupform.dbuser.value != "") { document.setupform.submit(); } else { alert(msg); }';
		}
		
		$this->_oStepTemplate->set("s", "NEXT", '<input id="Next" type="image" src="../admin/images/submit.gif" style="width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'../admin/images/submit.gif\');" onmouseout="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit.gif\\\');\'; } else { this.src=\'../admin/images/submit.gif\'; }" onmouseover="if (isMSIE) { this.style.filter = \'progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\\\'../admin/images/submit_hover.gif\\\');\'; } else { this.src=\'../admin/images/submit_hover.gif\'; }" onload="this.imgnormal = \'../admin/images/submit.gif\'; this.imgover = \'../admin/images/submit_hover.gif\'; this.clickimgnormal = \'\'; this.clickimgover = \'\'; if (!this.init) {IEAlphaInit(this); IEAlphaApply(this, this.imgnormal); this.init = true;}" onclick="document.setupform.step.value = \''.$this->_bNextstep.'\';">');
		
		$this->_oStepTemplate->set("s", "BACK", '<input id="Prev" type="image" src="images/controls/back.gif" style="margin-right: 10px; width: 16px; height: 16px; border: 0px none; progid:DXImageTransform.Microsoft.AlphaImageLoader(src=\'images/controls/back.gif\');" onclick="document.setupform.step.value = \''.$this->_bBackstep.'\';">');
	}			
}
?>
